=============
API Reference
=============

Complete reference for all public modules in *findiff*.

.. toctree::
    :maxdepth: 2

    diff
    coefs
    stencils
    pde
    compact
    vector
    symbolic
